@@ -1,7 +1,7 @@
 <?php
 
 /**
-  V5.07 18 Dec 2008   (c) 2000-2008 John Lim (jlim#natsoft.com). All rights reserved.
+  V5.10 10 Nov 2009   (c) 2000-2009 John Lim (jlim#natsoft.com). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence.
@@ -89,6 +89,8 @@ class ADODB2_mssql extends ADODB_DataDict {
 		case 'B': return 'IMAGE';
 			
 		case 'D': return 'DATETIME';
+		
+		case 'TS':
 		case 'T': return 'DATETIME';
 		case 'L': return 'BIT';
 		
@@ -151,7 +153,7 @@ class ADODB2_mssql extends ADODB_DataDict {
 	}
 	
 	// return string must begin with space
-	function _CreateSuffix($fname,$ftype,$fnotnull,$fdefault,$fautoinc,$fconstraint)
+	function _CreateSuffix($fname,&$ftype,$fnotnull,$fdefault,$fautoinc,$fconstraint,$funsigned)
 	{	
 		$suffix = '';
 		if (strlen($fdefault)) $suffix .= " DEFAULT $fdefault";
